CatBoostError

Struct CatBoostError 

pub struct CatBoostError { /* private fields */ }

Implementations

Source

impl CatBoostError

pub fn check_return_value(ret_val: bool) -> CatBoostResult<()>

Check the return value from an CatBoost FFI call, and return the last error message on error. Return values of true are treated as success, returns values of false are treated as errors.